[![Donate](https://img.shields.io/badge/donate-Coffee-yellow.svg)](https://www.buymeacoffee.com/renierm)
![Upload Python Package](https://github.com/RenierM26/pyUbersolar/workflows/Upload%20Python%20Package/badge.svg)

Library to control UberSolar Ubersmart devices

See __main__.py for example. Should be able to run python -m ubersolar as test.
